ProcError

Struct ProcError 

pub struct ProcError { /* private fields */ }
Available on crate feature proc only.
Error of termal procedural macro. Can be converted to a TokenStream that produces the error message or the message can be printed with the Display implementation.

Implementations

Source

impl ProcError

pub fn to_stream(self) -> TokenStream

Converts the error to a TokenStream that will produce the error at compile time.

pub fn span(&self) -> Span

Gets the Span of the error message.

This is the span that will be asociated with the compile time error.