Module progress

Module progress 

Available on crate feature progress only.

Structs

Bar
Customizable progress bar.
DefaultBarTheme
The default progress bar theme.
Dots
A progress tracker that uses triple dots.
Iter
Iterator tracking progress.
NoState
No state when tracking progress. This is the default.
Progress
The core type for tracking progress.

Enums

UpdatePolicy
Decides how often progress should update. This can be based either on iterations or time.

Traits

BarTheme
ProgressExt
ProgressFormatter
Decides how to display progress.
StateProgress
Represents state that can be converted to progress.

Functions

dots
A simple tracker that tracks only completion.
dots_try
A simple tracker that tracks only completion and failure.
track_bar
Track progress with progress bar.
track_dots
Track progress with progress dots.
try_track_bar
Track fallible progress with progress bar.
try_track_dots
Track fallible progress with progress dots.

Type Aliases

BarIter
Iterator tracking progress with progress bar.
DotsIter
Iterator tracking progress with progress bar.