TermRead

Struct TermRead 

pub struct TermRead<'t, 'p, P, T: IoProvider = StdioProvider>
where P: Predicate<Event>,
{ /* private fields */ }
Available on crate features raw and readers only.
Terminal reader. Supports only single line. Newlines are skipped.

Unstable API

API of TermRead will likely change in the future.

Implementations

Source

impl<'t, T: IoProvider> TermRead<'t, '_, KeyCode, T>

pub fn lines(term: &'t mut Terminal<T>) -> Self

Gets reader that ends on enter.

Source

impl<'t, 'p, P, T> TermRead<'t, 'p, P, T>
where P: Predicate<Event>, T: IoProvider,

pub fn new(term: &'t mut Terminal<T>, exit: P) -> Self

Creates new terminal reader that exits with the given predicate.

pub fn from_config( term: &'t mut Terminal<T>, exit: P, conf: ReadConf<'p>, ) -> Self

Create terminal reader from configuration.

pub fn edit_str(&mut self, s: &mut String, pos: Option<usize>) -> Result<()>

Edit the given string.

Errors
pub fn edit(&mut self, s: impl AsRef<str>, pos: Option<usize>) -> Result<String>

Edit the given string. Return new edited string (the old is unchanged).

Errors
pub fn edit_vec(&mut self, s: &mut Vec<char>, pos: Option<usize>) -> Result<()>

Edit the given vector. This is the most optimal edit as it doesn’t do any copy of the passed data.

Errors
pub fn read_to_str(&mut self, s: &mut String) -> Result<()>

Appends readed text to a string.

Errors
pub fn read_str(&mut self) -> Result<String>

Reads from console and returns the readed string.

Errors
pub fn finish_to_str(&mut self, s: &mut String) -> Result<()>

Continue reading all data and reset.

Errors
pub fn finish(&mut self) -> Result<String>

Continue reading all the data and reset.

Errors
pub fn get_input(&self) -> &[char]

Get the readed characters.

pub fn get_pos(&self) -> usize

Get the position of cursor within the readed characters.

pub fn set_edit(&mut self, s: impl AsRef<str>, pos: Option<usize>)

Set string to edit.

pub fn set_pos(&mut self, pos: Option<usize>)

Set the position within the buffer.

pub fn clear(&mut self)

Reset the buffer.

pub fn reshow(&mut self) -> Result<()>

Refresh the view.

Errors
pub fn set_prompt(&mut self, prompt: impl Into<TermText<'p>>)

Set the prompt.

pub fn configure(&mut self, conf: ReadConf<'p>)

Reconfigure the reader.

pub fn set_buf(&mut self, buf: Vec<char>, pos: Option<usize>)

Set the read buffer. It is filtered for non control characters.

pub unsafe fn read_one(&mut self) -> Result<bool>

Read one next character or nothing. Doesn’t block. Returns true if the input has ended and the result may be retrieved with TermRead::finish or TermRead::finish_to_str.

Errors
Safety

This is unsafe because calls to set_ functions may break the input if this is called.

pub fn is_finished(&self) -> bool

Check if the reading is finished.

pub fn set_end_condition(&mut self, c: P)

Sets the exit condition for the reader.

pub fn splice( &mut self, range: impl RangeBounds<usize>, it: impl IntoIterator<Item = char>, )

Modify the buffer. Control characters are ignored.

pub fn last_event(&self) -> Option<&Event>

Gets the last event.

pub fn queue(&mut self, evt: impl IntoIterator<Item = Event>)

Queue event to the reader.