Available on crate feature
progress only.Structs
- Bar
- Customizable progress bar.
- Default
BarTheme - The default progress bar theme.
- Dots
- A progress tracker that uses triple dots.
- Iter
- Iterator tracking progress.
- NoState
- No state when tracking progress. This is the default.
- Progress
- The core type for tracking progress.
Enums
- Update
Policy - Decides how often progress should update. This can be based either on iterations or time.
Traits
- BarTheme
- Progress
Ext - Progress
Formatter - Decides how to display progress.
- State
Progress - Represents state that can be converted to progress.
Functions
- dots
- A simple tracker that tracks only completion.
- dots_
try - A simple tracker that tracks only completion and failure.
- track_
bar - Track progress with progress bar.
- track_
dots - Track progress with progress dots.
- try_
track_ bar - Track fallible progress with progress bar.
- try_
track_ dots - Track fallible progress with progress dots.