pub struct TermRead<'t, 'p, P, T: IoProvider = StdioProvider>{ /* private fields */ }Available on crate features
raw and readers only.Expand description
Implementations
Sourceimpl<'t, T: IoProvider> TermRead<'t, '_, KeyCode, T>
impl<'t, T: IoProvider> TermRead<'t, '_, KeyCode, T>
Sourceimpl<'t, 'p, P, T> TermRead<'t, 'p, P, T>
impl<'t, 'p, P, T> TermRead<'t, 'p, P, T>
Sourcepub fn new(term: &'t mut Terminal<T>, exit: P) -> Self
pub fn new(term: &'t mut Terminal<T>, exit: P) -> Self
Creates new terminal reader that exits with the given predicate.
Sourcepub fn from_config(
term: &'t mut Terminal<T>,
exit: P,
conf: ReadConf<'p>,
) -> Self
pub fn from_config( term: &'t mut Terminal<T>, exit: P, conf: ReadConf<'p>, ) -> Self
Create terminal reader from configuration.
Sourcepub fn read_to_str(&mut self, s: &mut String) -> Result<()>
pub fn read_to_str(&mut self, s: &mut String) -> Result<()>
Sourcepub fn finish_to_str(&mut self, s: &mut String) -> Result<()>
pub fn finish_to_str(&mut self, s: &mut String) -> Result<()>
Sourcepub fn set_prompt(&mut self, prompt: impl Into<TermText<'p>>)
pub fn set_prompt(&mut self, prompt: impl Into<TermText<'p>>)
Set the prompt.
Sourcepub fn set_buf(&mut self, buf: Vec<char>, pos: Option<usize>)
pub fn set_buf(&mut self, buf: Vec<char>, pos: Option<usize>)
Set the read buffer. It is filtered for non control characters.
Sourcepub unsafe fn read_one(&mut self) -> Result<bool>
pub unsafe fn read_one(&mut self) -> Result<bool>
Read one next character or nothing. Doesn’t block. Returns true if
the input has ended and the result may be retrieved with
TermRead::finish or TermRead::finish_to_str.
Errors
Error::Ioon io write or read.
Safety
This is unsafe because calls to set_ functions may break the input if
this is called.
Sourcepub fn is_finished(&self) -> bool
pub fn is_finished(&self) -> bool
Check if the reading is finished.
Sourcepub fn set_end_condition(&mut self, c: P)
pub fn set_end_condition(&mut self, c: P)
Sets the exit condition for the reader.
Sourcepub fn splice(
&mut self,
range: impl RangeBounds<usize>,
it: impl IntoIterator<Item = char>,
)
pub fn splice( &mut self, range: impl RangeBounds<usize>, it: impl IntoIterator<Item = char>, )
Modify the buffer. Control characters are ignored.
Sourcepub fn last_event(&self) -> Option<&Event>
pub fn last_event(&self) -> Option<&Event>
Gets the last event.
Sourcepub fn queue(&mut self, evt: impl IntoIterator<Item = Event>)
pub fn queue(&mut self, evt: impl IntoIterator<Item = Event>)
Queue event to the reader.